@@ -6,8 +6,5 @@
     :copyright: (c) 2012 by Natan Lao.
     :license: BSD, see LICENSE for more details.
 """
-from soil import core, serving, util
-from soil.core import Soil
-
-__version__ = '0.1.3-dev'
+__version__ = '0.1.4-dev'
 __all__ = ['core', 'extensions', 'serving', 'shovel', 'test', 'util']
