@@ -15,12 +15,10 @@ import imp
 import os
 import re
 
-import soil
 from soil.util import status, getattr_nested
 
 from jinja2 import Environment, FileSystemLoader
 from termcolor import colored
-from werkzeug.wrappers import Response
 
 
 class Soil(object):
@@ -49,7 +47,7 @@ class Soil(object):
             for name in dir(ext):
                 if not name.startswith('_') and name.endswith('Extension'):
                     self.extensions[ext.__name__].append(
-                                                      getattr(ext, name)(self))
+                        getattr(ext, name)(self))
 
     def load_config(self):
         """Loads a soilcfg.py file and returns its contents in a dictionary.
@@ -157,5 +155,6 @@ class Soil(object):
 
         :param params: options to pass to :func:`werkzeug.serving.run_simple`.
         """
+        import soil.serving
         params.update(extra_files=self.watched_files)
         soil.serving.serve(self.config, self.projdir, **params)
