@@ -11,7 +11,7 @@
 import os
 import re
 
-from soil.core import Soil
+import soil.core
 
 from werkzeug.serving import run_simple
 from werkzeug.wrappers import Request, Response
@@ -19,7 +19,7 @@ from werkzeug.routing import Map, Rule
 from werkzeug.exceptions import HTTPException
 
 
-class SoilServer(Soil):
+class SoilServer(soil.core.Soil):
     """The Werkzeug application used to serve soil projects.
 
     :param projdir: the directory of the soil project
