@@ -17,7 +17,7 @@ import sys
 
 from shutil import copyfile
 
-import soil
+import soil.core
 from soil.util import status, skeleton_path
 from docopt import docopt
 from termcolor import colored
@@ -148,7 +148,7 @@ def main(argv):
         assert os.path.exists(os.path.join(proj, 'soilcfg.py')), \
                "Didn't find the project's `soilcfg.py`."
 
-        app = soil.Soil(os.path.realpath(proj))
+        app = soil.core.Soil(os.path.realpath(proj))
 
     if argv[1] == 'new':
         new(sys.argv[2])
